﻿'use strict';

var MyViewModel = function () {
    var self = this;

    self.contentType = "application/json;odata=verbose";
    self.contacts = ko.observableArray([]);
    self.currentText = ko.observable('');

    self.read = function () {
        $.ajax({
            url: '../_api/lists/getByTitle(\'Contacts\')/items',
            headers: { 'Accept': self.contentType },
            type: 'GET',
            success: function (data) {
                self.contacts(data.d.results);
            },
            error: function (err) {
                alert(err);
            }
        });
    };

    self.insert = function () {
        var obj = {
            Title: self.currentText(),
            __metadata: {
                type: 'SP.Data.ContactsListItem'
            }
        };
        self.getDigest().done(function (digest) {
            $.ajax({
                url: '../_api/lists/getByTitle(\'Contacts\')/items',
                headers: {
                    'Accept': self.contentType,
                    'content-type': self.contentType,
                    'X-RequestDigest': digest
                },
                data: JSON.stringify(obj),
                contentType: self.contentType,
                type: 'POST',
                success: function (data) {
                    self.read();
                },
                error: function (err) {
                    alert(err);
                }
            });
        });
    };

    self.getDigest = function () {
        var deferred = $.Deferred();
        $.ajax({
            url: '../_api/contextInfo',
            type: 'POST',
            contentType: self.contentType,
            headers: {
                'Accept': self.contentType,
                'content-type': self.contentType
            },
            success: function (data) {
                deferred.resolve(data.d.GetContextWebInformation.FormDigestValue);
            },
            error: function (jqXHR, textStatus, errorThrown) {
                alert(errorThrown);
            },
            async: false
        });
        return deferred.promise();
    };

    self.delete = function (id) {
        self.getDigest().done(function (digest) {
            $.ajax({
                url: '../_api/lists/getByTitle(\'Contacts\')/items(' + id + ')',
                headers: {
                    'Accept': self.contentType,
                    'content-type': self.contentType,
                    'X-RequestDigest': digest,
                    'X-HTTP-Method': 'DELETE',
                    'IF-MATCH': '*'
                },
                contentType: self.contentType,
                type: 'POST',
                success: function (data) {
                    self.read();
                },
                error: function (err) {
                    alert(err);
                }
            });
        });
    };

    self.edit = function (id, newTitle) {
        var obj = {
            Title: newTitle,
            __metadata: {
                type: 'SP.Data.ContactsListItem'
            }
        };
        self.getDigest().done(function (digest) {
            $.ajax({
                url: '../_api/lists/getByTitle(\'Contacts\')/items(' + id +')',
                headers: {
                    'Accept': self.contentType,
                    'content-type': self.contentType,
                    'X-RequestDigest': digest,
                    'X-HTTP-Method': 'MERGE',
                    'IF-MATCH': '*'
                },
                data: JSON.stringify(obj),
                contentType: self.contentType,
                type: 'POST',
                success: function (data) {
                    self.read();
                },
                error: function (err) {
                    alert(err);
                }
            });
        });
    };
};

$(document).ready(function () {
    var model = new MyViewModel();
    ko.applyBindings(model);

    model.read();
});